@@ -23,9 +23,6 @@ class OfflineWallet(object):
         self._svk = view_key or self._svk
         self._ssk = spend_key or self._ssk
 
-    def height(self):
-        raise WalletIsOffline()
-
     def spend_key(self):
         return self._ssk
 
@@ -38,37 +35,26 @@ class OfflineWallet(object):
     def accounts(self):
         return [Account(self, 0)]
 
-    def new_account(self, label=None):
-        raise WalletIsOffline()
-
     def addresses(self, account=0, addr_indices=None):
         if account == 0 and (addr_indices == [0] or addr_indices is None):
             return [self._address]
         raise WalletIsOffline()  # pragma: no cover (this should never happen)
 
-    def new_address(self, account=0, label=None):
+    def is_offline(self, *_, **__):
         raise WalletIsOffline()
 
-    def balances(self, account=0):
-        raise WalletIsOffline()
-
-    def transfers_in(self, account, pmtfilter):
-        raise WalletIsOffline()
-
-    def transfers_out(self, account, pmtfilter):
-        raise WalletIsOffline()
-
-    def export_outputs(self):
-        raise WalletIsOffline()
-
-    def import_outputs(self, outputs_hex):
-        raise WalletIsOffline()
-
-    def export_key_images(self):
-        raise WalletIsOffline()
-
-    def import_key_images(self, key_images):
-        raise WalletIsOffline()
-
-    def transfer(self, *args, **kwargs):
-        raise WalletIsOffline()
+    address_balance = (
+        balances
+    ) = (
+        export_key_images
+    ) = (
+        export_outputs
+    ) = (
+        height
+    ) = (
+        import_key_images
+    ) = (
+        import_outputs
+    ) = (
+        new_account
+    ) = new_address = transfer = transfers_in = transfers_out = sweep_all = is_offline
